Basic functionality.

- [X] show outstanding tasks in any Markdown file anywhere in the directory
- [X] be able to exclude set files from being considered
- [X] produce a summary of complete vs incomplete
- [X] document installation
- [X] document use
- [X] document `.whatnext` file structure
- [X] publish on pypi
